==> bitfront-library-6.0.0.tgz: package/src/app/shared/component/bit-toolbar.component.ts <==
import {Component,
    Input,
    Output,
    OnDestroy,
    EventEmitter,
    AfterViewInit,
    SimpleChange}   from '@angular/core';
import {Subscription}   from 'rxjs';

import {ToolbarService} from '../service/toolbar.service';
/** 
* Componenente que muestra una barra de botones. 
* @Input() componentId contiene el identificador del componente que contiene este toolbar. Es opcional en cuyo caso el valor será "BASE"
* @Output() onToolbarButtonPressed. El componente captura la pulsación de estos botones y envia un evento onToolbarButtonPressed con el nombre del 
* botón pulsado. 
**/ 
@Component({   

selector: 'bit-toolbar',
template: `
<!-- acciones no estandar definidas dinámicamente o muy particulares-->
<!-- si otherActionsDropdown viene a true y hay más de una acción, se muestran como un desplegable, si no, todas las acciones en línea -->
<div class="btn-group dropdown" role="group" *ngIf="mostrarOtherActionsEnDesplegable">
    <button type="button" *ngIf="otherActionsDropdown"
        class="btn btn-dinamico btn-accion dropdown-toggle" data-toggle="dropdown"
        aria-haspopup="true" aria-expanded="false">Accions&nbsp;&nbsp;<span class="fa fa-caret-right"></span></button>
    <div class="dropdown-menu desplegable-accion">
        <ng-container *ngFor="let button of (toolbar | otherToolbarAction)">
            <button type="button" 
                *ngIf="button.visible"
                [disabled]="!button.enable" (click)="otherAction(button)" class="btn btn-dinamico btn-accion dropdown-item"
            ><span [class]="button.estilo?button.estilo:'fa fa-caret-right'"></span>&nbsp;&nbsp;{{button.label}}</button>
        </ng-container>
    </div>
</div>

<!-- si otherActionsDropdown viene a false o solo hay una acción, se muestran una tras otra en línea -->
<div class="btn-inline" *ngIf="!mostrarOtherActionsEnDesplegable">
    <ng-container *ngFor="let button of (toolbar | otherToolbarAction)">
        <div *ngIf="button.visible" class="btn-group" role="group">
            <button type="button" [disabled]="!button.enable" (click)="otherAction(button)" class="btn btn-dinamico btn-accion">{{button.label}}&nbsp;&nbsp;<span [class]="button.estilo?button.estilo:'fa fa-caret'"></span></button>
        </div>
    </ng-container>
</div>

<!-- acciones estandar -->
<div class="btn-group" role="group" *ngIf="visible('new')">
    <button type="button" [disabled]="!enable('new')" (click)="newElement()" class="btn btn-danger">{{label('new', (femenino?'Nova':'Nou'))}}&nbsp;&nbsp;<span [class]="estilo('new', 'fa fa-plus')"></span></button>
</div>
<div class="btn-group" role="group" *ngIf="visible('add')">
    <button type="button" [disabled]="!enable('add')" (click)="add()" class="btn btn-danger">{{label('nova', 'Afegeix')}}&nbsp;&nbsp;<span [class]="estilo('add', 'fa fa-plus')"></span></button>
</div>
<!--div class="btn-group" role="group" *ngIf="visible('filter')">
    <button type="button" [disabled]="!enable('filter')" (click)="showFilter()" class="btn btn-transparent">{{label('filter', 'Mostra filtre')}}&nbsp;&nbsp;<span [class]="estilo('filter', 'glyphicon glyphicon-search')"></span></button>
</div-->
<div class="btn-group" role="group" *ngIf="visible('print')">
    <button type="button" [disabled]="!enable('print')" (click)="print()" class="btn btn-transparent">{{label('print', 'Imprimeix')}}&nbsp;&nbsp;<span [class]="estilo('print', 'glyphicon glyphicon-print')"></span></button>
</div>
<div class="btn-group" role="group" *ngIf="visible('export')">
    <button type="button" [disabled]="!enable('export')" (click)="exportData()" class="btn btn-transparent">{{label('export', 'Exporta')}}&nbsp;&nbsp;<span [class]="estilo('export', 'glyphicon glyphicon-file')"></span></button>
</div>
<div class="btn-group" role="group" *ngIf="visible('save')">
    <button type="button" [disabled]="!enable('save')" (click)="save()" class="btn btn-success">{{label('save', 'Desa')}}&nbsp;&nbsp;<span [class]="estilo('save', 'glyphicon glyphicon-floppy-disk')"></span></button>
</div>
<div class="btn-group" role="group" *ngIf="visible('delete')">
    <button type="button" [disabled]="!enable('delete')" (click)="delete()" class="btn btn-transparent btn-transparent-danger">{{label('delete', 'Elimina')}}&nbsp;&nbsp;<span [class]="estilo('delete', 'glyphicon glyphicon-remove')"></span></button>
</div>
`
})
export class BitToolbarComponent implements OnDestroy {
public static FILTER_BUTTON: string = "filter";
public static PRINT_BUTTON: string = "print";
public static EXPORT_BUTTON: string = "export";
public static NEW_BUTTON: string = "new";
public static SAVE_BUTTON: string = "save";
public static DELETE_BUTTON: string = "delete";
public static ADD_BUTTON: string = "add";

@Input("toolbar") toolbarOld: any = {}; // ya no se usa
@Input() femenino: boolean = false;     // género femenino (para los nombres de botones) o no
@Input() componentId: string = "BASE";  // id del componente donde está asociado el toolbar por defecto BASE
@Input() otherActionsDropdown: boolean = false; // determina si las "other actions" deben mostrarse en línea o como un desplegable
@Output() onToolbarButtonPressed = new EventEmitter<string>();

toolbar: any;
private toolbarService: ToolbarService;
private toolbarSubscription: Subscription;
mostrarOtherActionsEnDesplegable: boolean;

constructor(toolbarService: ToolbarService) { 
    this.toolbar = {};
    this.toolbarService = toolbarService;
}

ngAfterContentInit () {
    console.log(`soy el ToolbarComponent ${this.componentId}`);
    this.registerObservable();
}

registerObservable(){        
    this.toolbarSubscription = this.toolbarService.observableToolbar.subscribe(
        newToolbar => {    
            if (!newToolbar) {
                return; // un evento sin toolbar, no hay nada que hacer
            }                
            if (!this.componentId){ // si no tenemos componentId somos el único toolbar en pantalla, lo aceptamos sí o sí
                this.setToolbar(newToolbar);
            } else {
                // tenemos componentId, por lo que probablemente hay varios toolbar simultáneos en pantalla
                // comprobamos si el evento indica que ha cambiado el que nos interesa y, en caso contrario, lo ignoramos
                if (this.componentId === newToolbar.componentId){                
                    this.setToolbar(newToolbar);
                }
            }
        }
    );
}

enable(button: string): boolean {
    return this.toolbar[button] && this.toolbar[button].enable;
}

visible(button: string): boolean {
    return this.toolbar[button] && this.toolbar[button].visible;
}

label(button: string, defaultLabel: string): string {
    return (this.toolbar[button] && this.toolbar[button].label) || defaultLabel;
}

estilo(button: string, defaultValue: string): string {
    return (this.toolbar[button] && this.toolbar[button].estilo) || defaultValue || "fa fa-balance-spinner";
}

showFilter() {
    this.onToolbarButtonPressed.emit(BitToolbarComponent.FILTER_BUTTON);
}

print() {
    this.onToolbarButtonPressed.emit(BitToolbarComponent.PRINT_BUTTON);
}

exportData() {
    this.onToolbarButtonPressed.emit(BitToolbarComponent.EXPORT_BUTTON);
}

newElement() {
    this.onToolbarButtonPressed.emit(BitToolbarComponent.NEW_BUTTON);
}

add() {
    this.onToolbarButtonPressed.emit(BitToolbarComponent.ADD_BUTTON);
}

save() {
    this.onToolbarButtonPressed.emit(BitToolbarComponent.SAVE_BUTTON);
}

delete() {
    this.onToolbarButtonPressed.emit(BitToolbarComponent.DELETE_BUTTON);
}

otherAction(button: any){
    this.onToolbarButtonPressed.emit(button.action);
}

ngOnDestroy(){
    this.toolbarSubscription.unsubscribe();
}

setToolbar(newToolbar) {
    this.toolbar = newToolbar;

    // calcular si las other actions deben mostrarse en desplegable
    // (se ha pedido asi y hay más de una)
    let otherActionsVisibles = 0;
    for(let key in this.toolbar) {
        if(this.toolbar[key].otherAction && this.toolbar[key].visible) {
            otherActionsVisibles++;
        }
    }

    this.mostrarOtherActionsEnDesplegable = this.otherActionsDropdown && otherActionsVisibles > 1;
}

}

==> bitfront-library-6.6.2.tgz: package/src/app/shared/component/bit-toolbar.component.ts <==
import {Component,
    Input,
    Output,
    OnDestroy,
    EventEmitter,
    AfterViewInit,
    SimpleChange}   from '@angular/core';
import {Subscription}   from 'rxjs';

import {ToolbarService} from '../service/toolbar.service';
/** 
* Componenente que muestra una barra de botones. 
* @Input() componentId contiene el identificador del componente que contiene este toolbar. Es opcional en cuyo caso el valor será "BASE"
* @Output() onToolbarButtonPressed. El componente captura la pulsación de estos botones y envia un evento onToolbarButtonPressed con el nombre del 
* botón pulsado. 
**/ 
@Component({   

selector: 'bit-toolbar',
template: `
<!-- acciones no estandar definidas dinámicamente o muy particulares-->
<!-- si otherActionsDropdown viene a true y hay más de una acción, se muestran como un desplegable, si no, todas las acciones en línea -->
<div class="btn-group dropdown" role="group" *ngIf="mostrarOtherActionsEnDesplegable">
    <button type="button" *ngIf="otherActionsDropdown"
        class="btn btn-dinamico btn-accion dropdown-toggle" data-toggle="dropdown"
        aria-haspopup="true" aria-expanded="false">Accions&nbsp;&nbsp;<span class="fa fa-caret-right"></span></button>
    <div class="dropdown-menu desplegable-accion">
        <ng-container *ngFor="let button of (toolbar | otherToolbarAction)">
            <button type="button" 
                *ngIf="button.visible"
                [disabled]="!button.enable" (click)="otherAction(button)" class="btn btn-dinamico btn-accion dropdown-item"
            ><span [class]="button.estilo?button.estilo:'fa fa-caret-right'"></span>&nbsp;&nbsp;{{button.label}}</button>
        </ng-container>
    </div>
</div>

<!-- si otherActionsDropdown viene a false o solo hay una acción, se muestran una tras otra en línea -->
<div class="btn-inline" *ngIf="!mostrarOtherActionsEnDesplegable">
    <ng-container *ngFor="let button of (toolbar | otherToolbarAction)">
        <div *ngIf="button.visible" class="btn-group" role="group">
            <button type="button" [disabled]="!button.enable" (click)="otherAction(button)" class="btn btn-dinamico btn-accion">{{button.label}}&nbsp;&nbsp;<span [class]="button.estilo?button.estilo:'fa fa-caret-right'"></span></button>
        </div>
    </ng-container>
</div>

<!-- acciones estandar -->
<div class="btn-group" role="group" *ngIf="visible('new')">
    <button type="button" [disabled]="!enable('new')" (click)="newElement()" class="btn btn-danger">{{label('new', (femenino?'Nova':'Nou'))}}&nbsp;&nbsp;<span [class]="estilo('new', 'fa fa-plus')"></span></button>
</div>
<div class="btn-group" role="group" *ngIf="visible('add')">
    <button type="button" [disabled]="!enable('add')" (click)="add()" class="btn btn-danger">{{label('nova', 'Afegeix')}}&nbsp;&nbsp;<span [class]="estilo('add', 'fa fa-plus')"></span></button>
</div>
<!--div class="btn-group" role="group" *ngIf="visible('filter')">
    <button type="button" [disabled]="!enable('filter')" (click)="showFilter()" class="btn btn-transparent">{{label('filter', 'Mostra filtre')}}&nbsp;&nbsp;<span [class]="estilo('filter', 'glyphicon glyphicon-search')"></span></button>
</div-->
<div class="btn-group" role="group" *ngIf="visible('export')">
    <button type="button" [disabled]="!enable('export')" (click)="exportData()" class="btn btn-transparent">{{label('export', 'Exporta')}}&nbsp;&nbsp;<span [class]="estilo('export', 'glyphicon glyphicon-file')"></span></button>
</div>
<div class="btn-group" role="group" *ngIf="visible('save')">
    <button type="button" [disabled]="!enable('save')" (click)="save()" class="btn btn-success">{{label('save', 'Desa')}}&nbsp;&nbsp;<span [class]="estilo('save', 'glyphicon glyphicon-floppy-disk')"></span></button>
</div>
<div class="btn-group" role="group" *ngIf="visible('delete')">
    <button type="button" [disabled]="!enable('delete')" (click)="delete()" class="btn btn-transparent btn-transparent-danger">{{label('delete', 'Elimina')}}&nbsp;&nbsp;<span [class]="estilo('delete', 'glyphicon glyphicon-remove')"></span></button>
</div>
<div class="btn-group" role="group" *ngIf="visible('print')">
    <button type="button" [disabled]="!enable('print')" (click)="print()" class="btn btn-transparent">{{label('print', 'Imprimeix')}}&nbsp;&nbsp;<span [class]="estilo('print', 'glyphicon glyphicon-print')"></span></button>
</div>
<div class="btn-group" role="group" *ngIf="ayuda">
	<bit-boton-ayuda boton="true" [ayuda]="ayuda"></bit-boton-ayuda>
</div>
`
})
export class BitToolbarComponent implements OnDestroy {
public static FILTER_BUTTON: string = "filter";
public static PRINT_BUTTON: string = "print";
public static EXPORT_BUTTON: string = "export";
public static NEW_BUTTON: string = "new";
public static SAVE_BUTTON: string = "save";
public static DELETE_BUTTON: string = "delete";
public static ADD_BUTTON: string = "add";
public static HELP_BUTTON : string = "help";

@Input("toolbar") toolbarOld: any = {}; // ya no se usa
@Input("ayuda") ayuda: string; // clave de la ayuda contextual que mostrar para su botón
@Input() femenino: boolean = false;     // género femenino (para los nombres de botones) o no
@Input() componentId: string = "BASE";  // id del componente donde está asociado el toolbar por defecto BASE
@Input() otherActionsDropdown: boolean = false; // determina si las "other actions" deben mostrarse en línea o como un desplegable
@Output() onToolbarButtonPressed = new EventEmitter<string>();

toolbar: any;
private toolbarService: ToolbarService;
private toolbarSubscription: Subscription;
mostrarOtherActionsEnDesplegable: boolean;

constructor(toolbarService: ToolbarService) { 
    this.toolbar = {};
    this.toolbarService = toolbarService;
}

ngAfterContentInit () {
    console.log(`soy el ToolbarComponent ${this.componentId}`);
    this.registerObservable();
}

registerObservable(){        
    this.toolbarSubscription = this.toolbarService.observableToolbar.subscribe(
        newToolbar => {    
            if (!newToolbar) {
                return; // un evento sin toolbar, no hay nada que hacer
            }                
            if (!this.componentId){ // si no tenemos componentId somos el único toolbar en pantalla, lo aceptamos sí o sí
                this.setToolbar(newToolbar);
            } else {
                // tenemos componentId, por lo que probablemente hay varios toolbar simultáneos en pantalla
                // comprobamos si el evento indica que ha cambiado el que nos interesa y, en caso contrario, lo ignoramos
                if (this.componentId === newToolbar.componentId){                
                    this.setToolbar(newToolbar);
                }
            }
        }
    );
}

enable(button: string): boolean {
    return this.toolbar[button] && this.toolbar[button].enable;
}

visible(button: string): boolean {
    return this.toolbar[button] && this.toolbar[button].visible;
}

label(button: string, defaultLabel: string): string {
    return (this.toolbar[button] && this.toolbar[button].label) || defaultLabel;
}

estilo(button: string, defaultValue: string): string {
    return (this.toolbar[button] && this.toolbar[button].estilo) || defaultValue || "fa fa-balance-spinner";
}

showFilter() {
    this.onToolbarButtonPressed.emit(BitToolbarComponent.FILTER_BUTTON);
}

print() {
    this.onToolbarButtonPressed.emit(BitToolbarComponent.PRINT_BUTTON);
}

exportData() {
    this.onToolbarButtonPressed.emit(BitToolbarComponent.EXPORT_BUTTON);
}

newElement() {
    this.onToolbarButtonPressed.emit(BitToolbarComponent.NEW_BUTTON);
}

add() {
    this.onToolbarButtonPressed.emit(BitToolbarComponent.ADD_BUTTON);
}

save() {
    this.onToolbarButtonPressed.emit(BitToolbarComponent.SAVE_BUTTON);
}

delete() {
    this.onToolbarButtonPressed.emit(BitToolbarComponent.DELETE_BUTTON);
}

otherAction(button: any){
    this.onToolbarButtonPressed.emit(button.action);
}

ngOnDestroy(){
    this.toolbarSubscription.unsubscribe();
}

setToolbar(newToolbar) {
    this.toolbar = newToolbar;

    // calcular si las other actions deben mostrarse en desplegable
    // (se ha pedido asi y hay más de una)
    let otherActionsVisibles = 0;
    for(let key in this.toolbar) {
        if(this.toolbar[key].otherAction && this.toolbar[key].visible) {
            otherActionsVisibles++;
        }
    }

    this.mostrarOtherActionsEnDesplegable = this.otherActionsDropdown && otherActionsVisibles > 1;
}

}
